==> vst3sdk-docs-3.7.8_build_34-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/hierarchy.js <==
var hierarchy =
[
    [ "AudioBusBuffers", "structSteinberg_1_1Vst_1_1AudioBusBuffers.html", null ],
    [ "BusInfo", "structSteinberg_1_1Vst_1_1BusInfo.html", null ],
    [ "Chord", "structSteinberg_1_1Vst_1_1Chord.html", null ],
    [ "ChordEvent", "structSteinberg_1_1Vst_1_1ChordEvent.html", null ],
    [ "DataEvent", "structSteinberg_1_1Vst_1_1DataEvent.html", null ],
    [ "Event", "structSteinberg_1_1Vst_1_1Event.html", null ],
    [ "FrameRate", "structSteinberg_1_1Vst_1_1FrameRate.html", null ],
    [ "FUnknown", "../base/classSteinberg_1_1FUnknown.html", [
      [ "IPluginBase", "../base/classSteinberg_1_1IPluginBase.html", [
        [ "IComponent", "classSteinberg_1_1Vst_1_1IComponent.html", null ],
        [ "IEditController", "classSteinberg_1_1Vst_1_1IEditController.html", null ]
      ] ],
      [ "ITest", "classSteinberg_1_1ITest.html", null ],
      [ "ITestFactory", "classSteinberg_1_1ITestFactory.html", null ],
      [ "ITestResult", "classSteinberg_1_1ITestResult.html", null ],
      [ "ITestSuite", "classSteinberg_1_1ITestSuite.html", null ],
      [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", null ],
      [ "IAttributeList", "classSteinberg_1_1Vst_1_1IAttributeList.html", null ],
      [ "IAudioPresentationLatency", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", null ],
      [ "IAudioProcessor", "classSteinberg_1_1Vst_1_1IAudioProcessor.html", null ],
      [ "IAutomationState", "classSteinberg_1_1Vst_1_1IAutomationState.html", null ],
      [ "IComponentHandler", "classSteinberg_1_1Vst_1_1IComponentHandler.html", null ],
      [ "IComponentHandler2", "classSteinberg_1_1Vst_1_1IComponentHandler2.html", null ],
      [ "IComponentHandler3", "classSteinberg_1_1Vst_1_1IComponentHandler3.html", null ],
      [ "IComponentHandlerBusActivation", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html", null ],
      [ "IConnectionPoint", "classSteinberg_1_1Vst_1_1IConnectionPoint.html", null ],
      [ "IContextMenu", "classSteinberg_1_1Vst_1_1IContextMenu.html", null ],
      [ "IContextMenuTarget", "classSteinberg_1_1Vst_1_1IContextMenuTarget.html", null ],
      [ "IEditController2", "classSteinberg_1_1Vst_1_1IEditController2.html", null ],
      [ "IEditControllerHostEditing", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html", null ],
      [ "IEventList", "classSteinberg_1_1Vst_1_1IEventList.html", null ],
      [ "IHostApplication", "classSteinberg_1_1Vst_1_1IHostApplication.html", null ],
      [ "IInterAppAudioConnectionNotification", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html", null ],
      [ "IInterAppAudioHost", "classSteinberg_1_1Vst_1_1IInterAppAudioHost.html", null ],
      [ "IInterAppAudioPresetManager", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", null ],
      [ "IKeyswitchController", "classSteinberg_1_1Vst_1_1IKeyswitchController.html", null ],
      [ "IMessage", "classSteinberg_1_1Vst_1_1IMessage.html", null ],
      [ "IMidiLearn", "classSteinberg_1_1Vst_1_1IMidiLearn.html", null ],
      [ "IMidiMapping", "classSteinberg_1_1Vst_1_1IMidiMapping.html", null ],
      [ "INoteExpressionController", "classSteinberg_1_1Vst_1_1INoteExpressionController.html", null ],
      [ "INoteExpressionPhysicalUIMapping", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html", null ],
      [ "IParameterChanges", "classSteinberg_1_1Vst_1_1IParameterChanges.html", null ],
      [ "IParameterFinder", "classSteinberg_1_1Vst_1_1IParameterFinder.html", null ],
      [ "IParameterFunctionName", "classSteinberg_1_1Vst_1_1IParameterFunctionName.html", null ],
      [ "IParamValueQueue", "classSteinberg_1_1Vst_1_1IParamValueQueue.html", null ],
      [ "IPlugInterfaceSupport", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", null ],
      [ "IPrefetchableSupport", "classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", null ],
      [ "IProcessContextRequirements", "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", null ],
      [ "IProgramListData", "classSteinberg_1_1Vst_1_1IProgramListData.html", null ],
      [ "IProgress", "classSteinberg_1_1Vst_1_1IProgress.html", null ],
      [ "IStreamAttributes", "classSteinberg_1_1Vst_1_1IStreamAttributes.html", null ],
      [ "ITestPlugProvider", "classSteinberg_1_1Vst_1_1ITestPlugProvider.html", [
        [ "ITestPlugProvider2", "classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", null ]
      ] ],
      [ "IUnitData", "classSteinberg_1_1Vst_1_1IUnitData.html", null ],
      [ "IUnitHandler", "classSteinberg_1_1Vst_1_1IUnitHandler.html", null ],
      [ "IUnitHandler2", "classSteinberg_1_1Vst_1_1IUnitHandler2.html", null ],
      [ "IUnitInfo", "classSteinberg_1_1Vst_1_1IUnitInfo.html", null ],
      [ "IVst3ToAAXWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html", null ],
      [ "IVst3ToAUWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html", null ],
      [ "IVst3ToVst2Wrapper", "classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html", null ],
      [ "IVst3WrapperMPESupport", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html", null ],
      [ "IXmlRepresentationController", "classSteinberg_1_1Vst_1_1IXmlRepresentationController.html", null ]
    ] ],
    [ "IContextMenuItem", "structSteinberg_1_1Vst_1_1IContextMenuItem.html", null ],
    [ "KeyswitchInfo", "structSteinberg_1_1Vst_1_1KeyswitchInfo.html", null ],
    [ "LegacyMIDICCOutEvent", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent.html", null ],
    [ "NoteExpressionTextEvent", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html", null ],
    [ "NoteExpressionTypeInfo", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html", null ],
    [ "NoteExpressionValueDescription", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html", null ],
    [ "NoteExpressionValueEvent", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html", null ],
    [ "NoteOffEvent", "structSteinberg_1_1Vst_1_1NoteOffEvent.html", null ],
    [ "NoteOnEvent", "structSteinberg_1_1Vst_1_1NoteOnEvent.html", null ],
    [ "ParameterInfo", "structSteinberg_1_1Vst_1_1ParameterInfo.html", null ],
    [ "PhysicalUIMap", "structSteinberg_1_1Vst_1_1PhysicalUIMap.html", null ],
    [ "PhysicalUIMapList", "structSteinberg_1_1Vst_1_1PhysicalUIMapList.html", null ],
    [ "PolyPressureEvent", "structSteinberg_1_1Vst_1_1PolyPressureEvent.html", null ],
    [ "ProcessContext", "structSteinberg_1_1Vst_1_1ProcessContext.html", null ],
    [ "ProcessData", "structSteinberg_1_1Vst_1_1ProcessData.html", null ],
    [ "ProcessSetup", "structSteinberg_1_1Vst_1_1ProcessSetup.html", null ],
    [ "ProgramListInfo", "structSteinberg_1_1Vst_1_1ProgramListInfo.html", null ],
    [ "RepresentationInfo", "structSteinberg_1_1Vst_1_1RepresentationInfo.html", null ],
    [ "RoutingInfo", "structSteinberg_1_1Vst_1_1RoutingInfo.html", null ],
    [ "ScaleEvent", "structSteinberg_1_1Vst_1_1ScaleEvent.html", null ],
    [ "UnitInfo", "structSteinberg_1_1Vst_1_1UnitInfo.html", null ]
];

==> vst3sdk-docs-3.7.10_build_14-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/hierarchy.js <==
var hierarchy =
[
    [ "AudioBusBuffers", "structSteinberg_1_1Vst_1_1AudioBusBuffers.html", null ],
    [ "BusInfo", "structSteinberg_1_1Vst_1_1BusInfo.html", null ],
    [ "Chord", "structSteinberg_1_1Vst_1_1Chord.html", null ],
    [ "ChordEvent", "structSteinberg_1_1Vst_1_1ChordEvent.html", null ],
    [ "DataEvent", "structSteinberg_1_1Vst_1_1DataEvent.html", null ],
    [ "DataExchangeBlock", "structSteinberg_1_1Vst_1_1DataExchangeBlock.html", null ],
    [ "Event", "structSteinberg_1_1Vst_1_1Event.html", null ],
    [ "FrameRate", "structSteinberg_1_1Vst_1_1FrameRate.html", null ],
    [ "FUnknown", "../base/classSteinberg_1_1FUnknown.html", [
      [ "IPluginBase", "../base/classSteinberg_1_1IPluginBase.html", [
        [ "IComponent", "classSteinberg_1_1Vst_1_1IComponent.html", null ],
        [ "IEditController", "classSteinberg_1_1Vst_1_1IEditController.html", null ]
      ] ],
      [ "ITest", "classSteinberg_1_1ITest.html", null ],
      [ "ITestFactory", "classSteinberg_1_1ITestFactory.html", null ],
      [ "ITestResult", "classSteinberg_1_1ITestResult.html", null ],
      [ "ITestSuite", "classSteinberg_1_1ITestSuite.html", null ],
      [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", null ],
      [ "IAttributeList", "classSteinberg_1_1Vst_1_1IAttributeList.html", null ],
      [ "IAudioPresentationLatency", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", null ],
      [ "IAudioProcessor", "classSteinberg_1_1Vst_1_1IAudioProcessor.html", null ],
      [ "IAutomationState", "classSteinberg_1_1Vst_1_1IAutomationState.html", null ],
      [ "IComponentHandler", "classSteinberg_1_1Vst_1_1IComponentHandler.html", null ],
      [ "IComponentHandler2", "classSteinberg_1_1Vst_1_1IComponentHandler2.html", null ],
      [ "IComponentHandler3", "classSteinberg_1_1Vst_1_1IComponentHandler3.html", null ],
      [ "IComponentHandlerBusActivation", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html", null ],
      [ "IComponentHandlerSystemTime", "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html", null ],
      [ "IConnectionPoint", "classSteinberg_1_1Vst_1_1IConnectionPoint.html", null ],
      [ "IContextMenu", "classSteinberg_1_1Vst_1_1IContextMenu.html", null ],
      [ "IContextMenuTarget", "classSteinberg_1_1Vst_1_1IContextMenuTarget.html", null ],
      [ "IDataExchangeHandler", "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html", null ],
      [ "IDataExchangeReceiver", "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html", null ],
      [ "IEditController2", "classSteinberg_1_1Vst_1_1IEditController2.html", null ],
      [ "IEditControllerHostEditing", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html", null ],
      [ "IEventList", "classSteinberg_1_1Vst_1_1IEventList.html", null ],
      [ "IHostApplication", "classSteinberg_1_1Vst_1_1IHostApplication.html", null ],
      [ "IInterAppAudioConnectionNotification", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html", null ],
      [ "IInterAppAudioHost", "classSteinberg_1_1Vst_1_1IInterAppAudioHost.html", null ],
      [ "IInterAppAudioPresetManager", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", null ],
      [ "IKeyswitchController", "classSteinberg_1_1Vst_1_1IKeyswitchController.html", null ],
      [ "IMessage", "classSteinberg_1_1Vst_1_1IMessage.html", null ],
      [ "IMidiLearn", "classSteinberg_1_1Vst_1_1IMidiLearn.html", null ],
      [ "IMidiMapping", "classSteinberg_1_1Vst_1_1IMidiMapping.html", null ],
      [ "INoteExpressionController", "classSteinberg_1_1Vst_1_1INoteExpressionController.html", null ],
      [ "INoteExpressionPhysicalUIMapping", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html", null ],
      [ "IParameterChanges", "classSteinberg_1_1Vst_1_1IParameterChanges.html", null ],
      [ "IParameterFinder", "classSteinberg_1_1Vst_1_1IParameterFinder.html", null ],
      [ "IParameterFunctionName", "classSteinberg_1_1Vst_1_1IParameterFunctionName.html", null ],
      [ "IParamValueQueue", "classSteinberg_1_1Vst_1_1IParamValueQueue.html", null ],
      [ "IPlugInterfaceSupport", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", null ],
      [ "IPrefetchableSupport", "classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", null ],
      [ "IProcessContextRequirements", "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", null ],
      [ "IProgramListData", "classSteinberg_1_1Vst_1_1IProgramListData.html", null ],
      [ "IProgress", "classSteinberg_1_1Vst_1_1IProgress.html", null ],
      [ "IStreamAttributes", "classSteinberg_1_1Vst_1_1IStreamAttributes.html", null ],
      [ "ITestPlugProvider", "classSteinberg_1_1Vst_1_1ITestPlugProvider.html", [
        [ "ITestPlugProvider2", "classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", null ]
      ] ],
      [ "IUnitData", "classSteinberg_1_1Vst_1_1IUnitData.html", null ],
      [ "IUnitHandler", "classSteinberg_1_1Vst_1_1IUnitHandler.html", null ],
      [ "IUnitHandler2", "classSteinberg_1_1Vst_1_1IUnitHandler2.html", null ],
      [ "IUnitInfo", "classSteinberg_1_1Vst_1_1IUnitInfo.html", null ],
      [ "IVst3ToAAXWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html", null ],
      [ "IVst3ToAUWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html", null ],
      [ "IVst3ToVst2Wrapper", "classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html", null ],
      [ "IVst3WrapperMPESupport", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html", null ],
      [ "IXmlRepresentationController", "classSteinberg_1_1Vst_1_1IXmlRepresentationController.html", null ]
    ] ],
    [ "IContextMenuItem", "structSteinberg_1_1Vst_1_1IContextMenuItem.html", null ],
    [ "KeyswitchInfo", "structSteinberg_1_1Vst_1_1KeyswitchInfo.html", null ],
    [ "LegacyMIDICCOutEvent", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent.html", null ],
    [ "NoteExpressionTextEvent", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html", null ],
    [ "NoteExpressionTypeInfo", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html", null ],
    [ "NoteExpressionValueDescription", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html", null ],
    [ "NoteExpressionValueEvent", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html", null ],
    [ "NoteOffEvent", "structSteinberg_1_1Vst_1_1NoteOffEvent.html", null ],
    [ "NoteOnEvent", "structSteinberg_1_1Vst_1_1NoteOnEvent.html", null ],
    [ "ParameterInfo", "structSteinberg_1_1Vst_1_1ParameterInfo.html", null ],
    [ "PhysicalUIMap", "structSteinberg_1_1Vst_1_1PhysicalUIMap.html", null ],
    [ "PhysicalUIMapList", "structSteinberg_1_1Vst_1_1PhysicalUIMapList.html", null ],
    [ "PolyPressureEvent", "structSteinberg_1_1Vst_1_1PolyPressureEvent.html", null ],
    [ "ProcessContext", "structSteinberg_1_1Vst_1_1ProcessContext.html", null ],
    [ "ProcessData", "structSteinberg_1_1Vst_1_1ProcessData.html", null ],
    [ "ProcessSetup", "structSteinberg_1_1Vst_1_1ProcessSetup.html", null ],
    [ "ProgramListInfo", "structSteinberg_1_1Vst_1_1ProgramListInfo.html", null ],
    [ "RepresentationInfo", "structSteinberg_1_1Vst_1_1RepresentationInfo.html", null ],
    [ "RoutingInfo", "structSteinberg_1_1Vst_1_1RoutingInfo.html", null ],
    [ "ScaleEvent", "structSteinberg_1_1Vst_1_1ScaleEvent.html", null ],
    [ "UnitInfo", "structSteinberg_1_1Vst_1_1UnitInfo.html", null ]
];
